import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_system/senior_design_system.dart';

import '../page_wrapper.dart';
import '../panel.dart';

class TextFieldExample extends StatelessWidget {
  const TextFieldExample({Key? key}) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return PageWrapper(
      title: 'Text Field Example',
      content: SingleChildScrollView(
        child: Padding(
          padding: const EdgeInsets.all(16.0),
          child: Column(
            children: [
              Panel(
                title: 'Normal',
                content: SeniorTextField(
                  hintText: 'Nome',
                  maxLines: null,
                  maxLength: 43,
                  counterCaracterLabel: 'words',
                ),
              ),
              Panel(
                title: 'Text area',
                content: SeniorTextField(
                  hintText: 'Descrição',
                  maxLines: 10,
                ),
              ),
              Panel(
                title: 'Limite caracteres',
                content: SeniorTextField(
                  label: 'Nome',
                  maxLength: 10,
                  maxLines: null,
                ),
              ),
              Panel(
                title: 'Com validator',
                content: SeniorTextField(
                  maxLength: 30,
                  label: 'Sobrenome',
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                ),
              ),
              Panel(
                title: 'Campo de senha',
                content: SeniorTextField.password(
                  label: 'Senha',
                  validator: (value) {
                    return value == null || value.isEmpty
                        ? 'Campo obrigatório'
                        : null;
                  },
                  textInputAction: TextInputAction.next,
                ),
              ),
              Panel(
                title: 'Ícone à esquerda',
                content: SeniorTextField(
                  label: 'Início',
                  leftIcon: FontAwesomeIcons.calendar,
                ),
              ),
              Panel(
                title: 'Ícone à direita',
                content: SeniorTextField(
                  label: 'Fim',
                  rightIcon: FontAwesomeIcons.calendar,
                ),
              ),
            ],
          ),
        ),
      ),
    );
  }
}
