# SeniorTextField class

Use SeniorTextField para adicionar widgets do tipo text field com as definições do Senior Design System no seu layout.

## Herança

Object > DiagnosticableTree > Widget > __StatefulWidget__

## Construtores

* SeniorTextField({
    Key? key,
    String? label,
    IconData? leftIcon,
    IconData? rightIcon,
    String? helper,
    String? hintText,
    bool disabled = false,
    String? initialValue,
    String? Function(T?) validator,
    int? maxLength,
    int? minLines,
    int? maxLines = 1,
    bool autocorrect = true,
    bool readOnly = false,
    Function(String)? onChanged,
    Function()? onTap,
    Function()? onEditingComplete,
    bool autofocus = false,
    TextEditingController? controller,
    TextInputType? keyboardType,
    bool obscureText = false,
}) ... __const__

## Propriedades

| Property          | Type                  | Description                                                                                                                | Required | Default |
| ----------------- | --------------------- | -------------------------------------------------------------------------------------------------------------------------- | -------- | ------- |
| key               | Key                   | Controla como um widget substitui outro widget na árvore.                                                                  | Não      |         |
| label             | String                | Texto de identificação para o text field.                                                                                  | Não      |         |
| leftIcon          | IconData              | Adiciona um ícone posicionado à esquerda.                                                                                  | Não      |         |
| rightIcon         | IconData              | Adiciona um ícone posicionado à direita.                                                                                   | Não      |         |
| helper            | String                | Texto com dica apresentado abaixo do text field.                                                                           | Não      |         |
| hintText          | String                | Texto com dica apresentado dentro do text field.                                                                           | Não      |         |
| disabled          | bool                  | Determina se o text field estará desabilitado.                                                                             | Não      | false   |
| initialValue      | String                | Valor inicial que para o text field.                                                                                       | Não      |         |
| validator         | FormFieldValidator    | Um método opcional que valida uma entrada. Retorna uma string de erro se a entrada for inválida ou nula caso contrário.    | Não      |         |
| maxLength         | int                   | Tamanho máximo para o texto digitado.                                                                                      | Não      |         |
| minLines          | int                   | Quantidade mínima de linhas para o campo                                                                                   | Não      |         |
| maxLines          | int                   | Quantidade máxima de linhas para o campo. null para indeterminado.                                                         | Não      | 1       |
| autocorrect       | bool                  | Determina se deve habilitar a autocorreção.                                                                                | Não      | true    |
| readOnly          | bool                  | Determina se o text field será apenas leitura.                                                                             | Não      | false   |
| onChanged         | Function(String)      | Função chamada quando ocorre uma alteração no valor do TextField: ao inserir ou excluir texto.                             | Não      |         |
| onTap             | Function()            | Função chamada para cada toque distinto, exceto para cada segundo toque de um toque duplo.                                 | Não      |         |
| onEditingComplete | Function()            | Função chamada quando o usuário envia conteúdo editável (por exemplo, o usuário pressiona o botão "concluído" no teclado). | Não      |         |
| autofocus         | bool                  | Determina se este campo de texto deve receber foco, se nada mais já estiver focado.                                        | Não      | false   |
| controller        | TextEditingController | Controller para o texto que está sendo editado.                                                                            | Não      |         |
| keyboardType      | TextInputType         | Determina o tipo de teclado a ser usado para editar o texto.                                                               | Não      |         |
| obscureText       | bool                  | Determina se deve ocultar o texto que está sendo editado (por exemplo, para senhas).                                       | Não      | false   |