import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_tokens/tokens/senior_colors.dart';

class SeniorColorfulHeaderStructure extends StatefulWidget {
  const SeniorColorfulHeaderStructure({
    Key? key,
    required this.title,
    required this.body,
    this.leading,
    this.actions,
    this.hasTopPadding = true,
    this.colors,
  }) : super(
          key: key,
        );

  final Widget title;
  final Widget? leading;
  final List<Widget>? actions;
  final Widget body;
  final bool hasTopPadding;
  final List<Color>? colors;

  @override
  State<SeniorColorfulHeaderStructure> createState() =>
      _SeniorColorfulHeaderStructureState();
}

class _SeniorColorfulHeaderStructureState
    extends State<SeniorColorfulHeaderStructure> {
  @override
  Widget build(BuildContext context) {
    return Container(
      decoration: BoxDecoration(
        gradient: LinearGradient(
          colors: widget.colors ?? SeniorColors.primaryGradientColors,
        ),
      ),
      child: Column(
        children: [
          AppBar(
            leading: widget.leading,
            elevation: 0,
            backgroundColor: Colors.transparent,
            actions: widget.actions,
            title: widget.title,
            centerTitle: false,
          ),
          Expanded(
            child: Container(
              padding: EdgeInsets.only(
                top: widget.hasTopPadding ? SeniorRadius.huge : 0,
              ),
              decoration: BoxDecoration(
                borderRadius: BorderRadius.only(
                  topLeft: Radius.circular(
                    SeniorRadius.huge,
                  ),
                  topRight: Radius.circular(
                    SeniorRadius.huge,
                  ),
                ),
                color: SeniorColors.pureWhite,
              ),
              child: widget.body,
            ),
          )
        ],
      ),
    );
  }
}
