import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorContactBookItem extends StatelessWidget {
  final String? title;
  final List<String>? items;
  final Function()? onTap;
  final EdgeInsets padding;

  const SeniorContactBookItem({
    Key? key,
    this.title,
    this.items,
    this.onTap,
    this.padding = const EdgeInsets.symmetric(
      horizontal: SeniorSpacing.xbig,
      vertical: SeniorSpacing.normal,
    ),
  }) : super(key: key);

  Widget _buildItems(List<String>? items) {
    return items != null
        ? Column(
            crossAxisAlignment: CrossAxisAlignment.start,
            children: items
                .map((item) => Text(
                      item,
                      style: SeniorTypography.small(
                        color: SeniorColors.neutralColor500,
                      ),
                    ))
                .toList(),
          )
        : SizedBox.shrink();
  }

  @override
  Widget build(BuildContext context) {
    return InkWell(
      onTap: onTap,
      child: Container(
        padding: padding,
        child: Column(
          crossAxisAlignment: CrossAxisAlignment.start,
          children: [
            title == null
                ? SizedBox.shrink()
                : Container(
                    padding: items != null
                        ? const EdgeInsets.only(bottom: SeniorSpacing.xxsmall)
                        : null,
                    child: Text(
                      title!,
                      style: SeniorTypography.body(
                        color: SeniorColors.neutralColor800,
                      ),
                    ),
                  ),
            _buildItems(items),
          ],
        ),
      ),
    );
  }
}
