import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorDraggableItem {
  final Key? key;
  final String text;
  final Color color;

  const SeniorDraggableItem({
    this.key,
    required this.text,
    required this.color,
  });
}

class SeniorDraggableList extends StatefulWidget {
  final List<SeniorDraggableItem> items;
  final EdgeInsetsGeometry? padding;

  const SeniorDraggableList({
    Key? key,
    required this.items,
    this.padding,
  }) : super(
    key: key,
  );

  @override
  State<SeniorDraggableList> createState() => _SeniorDraggableListState();
}

class _SeniorDraggableListState extends State<SeniorDraggableList> {
  Widget buildContent(SeniorDraggableItem item) {
    return Container(
      key: item.key,
      margin: const EdgeInsets.symmetric(vertical: SeniorSpacing.xsmall),
      padding: const EdgeInsets.all(SeniorSpacing.xsmall),
      decoration: BoxDecoration(
        color: item.color,
        borderRadius: BorderRadius.circular(SeniorRadius.small),
      ),
      child: Row(
        children: [
          Expanded(
            child: Center(
              child: Text(
                item.text,
                style: SeniorTypography.smallBold(
                  color: SeniorColors.pureWhite,
                ),
              ),
            ),
          ),
          FaIcon(
            FontAwesomeIcons.sort,
            size: SeniorTypographyIconSize.body,
            color: SeniorColors.pureWhite,
          ),
        ],
      ),
    );
  }

  void onReorder(int oldIndex, int newIndex) {
    if (oldIndex < newIndex) {
      int end = newIndex - 1;
      int i = 0;
      int local = oldIndex;
      SeniorDraggableItem startItem = widget.items[oldIndex];
      do {
        widget.items[local] = widget.items[++local];
        i++;
      } while (i < end - oldIndex);
      widget.items[end] = startItem;
    }
    // dragging from bottom to top
    else if (oldIndex > newIndex) {
      var startItem = widget.items[oldIndex];
      for (int i = oldIndex; i > newIndex; i--) {
        widget.items[i] = widget.items[i - 1];
      }
      widget.items[newIndex] = startItem;
    }
    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Padding(
      padding: widget.padding ?? const EdgeInsets.all(0),
      child: Theme(
        data: ThemeData(
          canvasColor: Colors.transparent,
        ),
        child: ReorderableListView(          
          children: widget.items.map((item) => buildContent(item)).toList(),
          onReorder: onReorder,
        ),
      ),
    );
  }
}