import 'package:flutter/material.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorInfoCardTheme {
  SeniorInfoCardTheme._();

  static Color getCardColor({required Brightness theme}) {
    return SeniorColors.neutralColor100;
  }

  static Color getNumberColor({required Brightness theme}) {
    return SeniorColors.neutralColor800;
  }

  static Color getLabelColor({required Brightness theme}) {
    return SeniorColors.neutralColor600;
  }
}

class SeniorInfoCard extends StatelessWidget {
  final Color severityColor;
  final String label;
  final String value;
  final FocusNode? focusNode;
  final bool canRequestFocus;
  final Function()? onTap;
  final Function()? onDoubleTap;
  final Function()? onLongPress;
  final Function(bool)? onFocusChange;
  final bool fullLength;

  const SeniorInfoCard({
    Key? key,
    required this.label,
    required this.value,
    required this.severityColor,
    this.focusNode,
    this.canRequestFocus = true,
    this.onTap,
    this.onDoubleTap,
    this.onLongPress,
    this.onFocusChange,
    this.fullLength = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    Brightness theme = MediaQuery.of(context).platformBrightness;

    return InkWell(
      focusNode: focusNode,
      canRequestFocus: canRequestFocus,
      onTap: onTap,
      onDoubleTap: onDoubleTap,
      onLongPress: onLongPress,
      onFocusChange: onFocusChange,
      child: Container(
        constraints: BoxConstraints(
          minHeight: 104.0,
          maxWidth: fullLength ? double.infinity : 104.0,
        ),
        padding: EdgeInsets.fromLTRB(0, 16.0, 0, 0),
        decoration: BoxDecoration(
          color: SeniorColors.neutralColor100,
          borderRadius: const BorderRadius.all(Radius.circular(SeniorRadius.xbig)),
        ),
        child: Column(
          mainAxisAlignment: MainAxisAlignment.spaceBetween,
          children: [
            Container(                
              child: Column(
                mainAxisAlignment: MainAxisAlignment.center,
                children: [
                  Padding(
                    padding: const EdgeInsets.only(bottom: 4.0),
                    child: Text(
                      value,
                      maxLines: null,
                      style: SeniorTypography.h1(color: SeniorInfoCardTheme.getNumberColor(theme: theme)),
                    ),
                  ),
                  Text(
                    label,
                    textAlign: TextAlign.center,
                    style: SeniorTypography.small(color: SeniorInfoCardTheme.getLabelColor(theme: theme)),
                  ),
                ],
              ),
            ),
            Container(
              height: 4.0,
              width: double.maxFinite,
              decoration: BoxDecoration(
                color: severityColor,
                borderRadius: const BorderRadius.only(
                  bottomLeft: Radius.circular(SeniorRadius.xbig),
                  bottomRight: Radius.circular(SeniorRadius.xbig)
                ),
              ),
            ),
          ],
        ),
      ),
    );
  }
}
