import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:senior_design_tokens/tokens/senior_spacing.dart';

enum ThumbsOptions { thumbsUp, thumbsDown }

class SeniorMessageCardFeedbackInfo {
  final String message;
  bool isThumbsUp;
  bool isThumbsDown;
  final Function(bool thumbsUp, bool thumbsDown) onChangedFeedback;

  SeniorMessageCardFeedbackInfo({
    required this.message,
    required this.isThumbsUp,
    required this.isThumbsDown,
    required this.onChangedFeedback,
  });
}

class SeniorMessageCard extends StatefulWidget {
  final String message;
  final SeniorMessageCardFeedbackInfo? feedbackInfo;
  final EdgeInsetsGeometry? margin;

  SeniorMessageCard({
    Key? key,
    required this.message,
    this.feedbackInfo,
    this.margin,
  }) : super(key: key);

  @override
  State<SeniorMessageCard> createState() => _SeniorMessageCardState();
}

class _SeniorMessageCardState extends State<SeniorMessageCard> {
  final ScrollController scrollController = ScrollController();

  void changeFeedback(ThumbsOptions option) {
    if(widget.feedbackInfo == null) {
      return;
    }

    SeniorMessageCardFeedbackInfo feedback = widget.feedbackInfo!;

    switch (option) {
      case ThumbsOptions.thumbsUp:
        if (feedback.isThumbsUp) {
          feedback.isThumbsUp = false;
        } else {
          feedback.isThumbsUp = true;
          feedback.isThumbsDown = false;
        }
        break;
      case ThumbsOptions.thumbsDown:
      default:
        if (feedback.isThumbsDown) {
          feedback.isThumbsDown = false;
        } else {
          feedback.isThumbsUp = false;
          feedback.isThumbsDown = true;
        }
        break;
    }

    feedback.onChangedFeedback(feedback.isThumbsUp, feedback.isThumbsDown);

    setState(() {});
  }

  @override
  Widget build(BuildContext context) {
    return Container(
      margin: widget.margin ?? const EdgeInsets.all(0),
      width: double.infinity,
      decoration: BoxDecoration(
        color: SeniorColors.secondaryColor100,
        borderRadius: BorderRadius.circular(SeniorRadius.xbig),
      ),
      child: Stack(
        children: [
          Padding(
            padding: EdgeInsets.only(
              top: SeniorSpacing.xmedium,
              bottom: widget.feedbackInfo != null
                  ? SeniorSpacing.xxhuge
                  : SeniorSpacing.xmedium,
              right: SeniorSpacing.xxsmall,
            ),
            child: Scrollbar(
              isAlwaysShown: true,
              controller: scrollController,
              child: SingleChildScrollView(
                controller: scrollController,
                padding: EdgeInsets.symmetric(
                  horizontal: SeniorSpacing.normal,
                ),
                child: Text(
                  widget.message,
                  style: SeniorTypography.body(
                    color: SeniorColors.pureBlack,
                  ),
                ),
              ),
            ),
          ),
          widget.feedbackInfo != null
          ? Positioned(
            bottom: SeniorSpacing.normal,
            right: SeniorSpacing.big,
            left: SeniorSpacing.xbig,
            child: Container(
              child: Row(
                mainAxisAlignment: MainAxisAlignment.spaceBetween,
                children: [
                  Text(
                          widget.feedbackInfo!.message,
                          style: SeniorTypography.small(
                            color: SeniorColors.neutralColor600,
                          ),
                        ),
                  Container(
                    child: Row(
                      children: [
                        InkWell(
                          onTap: () {
                            changeFeedback(ThumbsOptions.thumbsUp);
                          },
                          child: FaIcon(
                            widget.feedbackInfo!.isThumbsUp
                                ? FontAwesomeIcons.solidThumbsUp
                                : FontAwesomeIcons.thumbsUp,
                            color: SeniorColors.neutralColor600,
                            size: SeniorTypographyIconSize.CTA,
                          ),
                        ),
                        SizedBox(width: SeniorSpacing.small),
                        InkWell(
                          onTap: () {
                            changeFeedback(ThumbsOptions.thumbsDown);
                          },
                          child: FaIcon(
                            widget.feedbackInfo!.isThumbsDown
                                ? FontAwesomeIcons.solidThumbsDown
                                : FontAwesomeIcons.thumbsDown,
                            color: SeniorColors.neutralColor600,
                            size: SeniorTypographyIconSize.CTA,
                          ),
                        ),
                      ],
                    ),
                  ),
                ],
              ),
            ),
          )
          : SizedBox.shrink(),
        ],
      ),
    );
  }
}