import 'package:flutter/material.dart';
import 'package:senior_design_system/widgets/senior_button.dart';
import 'package:senior_design_tokens/tokens/senior_colors.dart';
import 'package:senior_design_tokens/tokens/senior_typography.dart';

class SeniorModal extends StatelessWidget {
  final String title;
  final String content;
  final SeniorButton? actionButton;
  final SeniorButton ghostButton;

  const SeniorModal({
    Key? key,
    required this.title,
    required this.content,
    this.actionButton,
    required this.ghostButton,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return AlertDialog(
      title: Text(
        title,
        style: SeniorTypography.h3(
          color: SeniorColors.neutralColor800,
        ),
      ),
      titlePadding: EdgeInsets.only(
        top: 16,
        right: 16,
        left: 16,
        bottom: 8,
      ),
      contentPadding: EdgeInsets.only(
        left: 16,
        right: 16,
        bottom: 16,
      ),
      content: Column(
        mainAxisSize: MainAxisSize.min,
        children: [
          Text(
            content,
            style: SeniorTypography.text(
              color: SeniorColors.secondaryColor,
            ),
          ),
          SizedBox(
            height: 8,
          ),
          actionButton ?? SizedBox.shrink(),
          SizedBox(
            height: 8,
          ),
          ghostButton
        ],
      ),
    );
  }
}
