import 'package:flutter/material.dart';
import 'package:senior_design_system/senior_design_system.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';

class SeniorProfilePicture extends StatelessWidget {
  const SeniorProfilePicture({
    Key? key,
    required this.radius,
    required this.employeeName,
    this.isLoading = false,
    this.imageProvider,
  }) : super(key: key);

  final bool isLoading;
  final double radius;
  final String employeeName;
  final ImageProvider? imageProvider;

  String _getInitials() {
    List<String> names = employeeName.split(" ");
    String initials = '';
    for (var i = 0; i < names.length; i++) {
      if (initials.length != 2) {
        initials += '${names[i].substring(0, 1)}';
      }
    }
    return initials;
  }

  @override
  Widget build(BuildContext context) {
    return Stack(
      children: [
        CircleAvatar(
          backgroundColor: SeniorColors.secondaryColor400,
          radius: radius,
          backgroundImage: imageProvider,
          child: Offstage(
            offstage: imageProvider != null,
            child: Text(
              _getInitials().toUpperCase(),
              style: SeniorTypography.title(
                color: SeniorColors.pureBlack,
              ),
            ),
          ),
        ),
        isLoading
            ? CircleAvatar(
                backgroundColor: SeniorColors.pureWhite.withOpacity(.5),
                radius: radius,
                child: SeniorLoading(),
              )
            : SizedBox.shrink(),
      ],
    );
  }
}
