import 'package:flutter/material.dart';
import 'package:font_awesome_flutter/font_awesome_flutter.dart';
import 'package:senior_design_tokens/senior_design_tokens.dart';
import 'package:flutter_rating_bar/flutter_rating_bar.dart';

class SeniorRating extends StatelessWidget {
  final int itemCount;
  final double initialRating;
  final Function(double) onRatingUpdate;
  final bool allowHalfRating;
  final Axis direction;
  final bool ignoreGestures;
  final double itemSize;
  final EdgeInsetsGeometry itemPadding;
  final bool disabled;

  const SeniorRating({
    Key? key,
    required this.itemCount,
    required this.initialRating,
    required this.onRatingUpdate,
    this.allowHalfRating = false,
    this.direction = Axis.horizontal,
    this.ignoreGestures = false,
    this.itemSize = 16.0,
    this.itemPadding = const EdgeInsets.symmetric(horizontal: 4.0),
    this.disabled = false,
  }) : super(key: key);

  @override
  Widget build(BuildContext context) {
    return RatingBar(
      itemSize: itemSize,
      initialRating: initialRating,
      onRatingUpdate: onRatingUpdate,
      direction: direction,
      allowHalfRating: allowHalfRating,
      itemCount: itemCount,
      ignoreGestures: disabled || ignoreGestures,
      ratingWidget: RatingWidget(
        full: Icon(
          FontAwesomeIcons.solidStar,
          color: disabled
              ? SeniorColors.secondaryColor600
              : SeniorColors.manchesterColorOrange300,
          size: SeniorTypographyIconSize.CTA,
        ),
        half: Icon(
          FontAwesomeIcons.starHalfAlt,
          color: disabled
              ? SeniorColors.secondaryColor600
              : SeniorColors.manchesterColorOrange300,
          size: SeniorTypographyIconSize.CTA,
        ),
        empty: Icon(
          FontAwesomeIcons.star,
          color: disabled
              ? SeniorColors.secondaryColor600
              : SeniorColors.manchesterColorOrange300,
          size: SeniorTypographyIconSize.CTA,
        ),
      ),
      itemPadding: itemPadding,
    );
  }
}
