#!/bin/bash

set -e # Exit at first error

# Import release helpers
. senior-ci/common/release-helpers.sh

# Import notification helpers
. senior-ci/common/notification-helpers.sh

# Import Senior CI Extensions
. senior-ci/common/senior-ci-extensions-helpers.sh


update_ci_vars() {
    if [ -z "$CQAT_URL" -o -z "$UPDATE_VARS" ]; then
        echo 'As variáveis SCI_VERSION_TAG_FRONTEND, SCI_VERSION_TAG_BACKEND e SCI_TEST_ON_SEND_SONAR não serão atualizadas nos grupos, pois as variáveis CQAT_URL e UPDATE_VARS não estão definidas'
    else
        echo 'Atualizando variáveis SCI_VERSION_TAG_FRONTEND, SCI_VERSION_TAG_BACKEND e SCI_TEST_ON_SEND_SONAR em todos os grupos...'
        echo "SCI_VERSION_TAG_FRONTEND e SCI_VERSION_TAG_BACKEND = $VERSION_HYPHEN"
        echo "SCI_TEST_ON_SEND_SONAR = true"

        DATA='{ '
          DATA+='"query":"mutation($variableName: String!, $variableValue: String, $versionOfSeniorCI: String) { '
            DATA+='manageGitlabGroupVars(name: $variableName, value: $variableValue) { successCount, failureCount }, '
            DATA+='updateVersionVars(version: $versionOfSeniorCI) { success, reason } '
          DATA+='}",'
          DATA+='"variables":{ "variableName":"SCI_TEST_ON_SEND_SONAR", "variableValue":"true", "versionOfSeniorCI":"'$VERSION_HYPHEN'" } '
        DATA+='}'

        curl "$CQAT_URL"/graphql \
            -X POST \
            -H 'Content-Type: application/json' \
            --data "$DATA"
    fi
}

SONAR_URL="http://sonar.senior.com.br"

getopts "ruas" op;
case "$op" in
  r)  echo "[CI] Starting Self-Release"
      unshallow_repo

      get_next_version $2

      call_extension "before_release"

      create_release_branch

      call_extension "before_change_changelog"

      update_changelog

      call_extension "after_change_changelog"

      create_release_tag

      call_extension "after_release"

      update_ci_vars

      notify_release_teams_channel
      ;;

  u)  echo "[CI] Atualizando variáveis do CI"
      unshallow_repo

      VERSION_HYPHEN=`git describe --tags --abbrev=0`

      update_ci_vars
      ;;
  a)  echo "[CI] Realizando análise do SonarQube - $SONAR_URL"
      VERSION="$CI_COMMIT_REF_SLUG"
      call_extension "before_sonar_preview"
      sonar-scanner -Dsonar.host.url=$SONAR_URL -Dsonar.projectKey=$CI_PROJECT_NAME -Dsonar.projectName=$CI_PROJECT_NAME -Dsonar.gitlab.project_id=$CI_PROJECT_ID -Dsonar.gitlab.commit_sha=$CI_BUILD_REF -Dsonar.gitlab.ref_name=$CI_BUILD_REF_NAME -Dsonar.issuesReport.console.enable=true  -Dsonar.sourceEncoding=UTF-8 -Dsonar.analysis.mode=preview -Dsonar.projectVersion=$VERSION
      call_extension "after_sonar_preview"
      ;;
  s)  echo "[CI] Realizando análise e publicação dos resultados no SonarQube - $SONAR_URL"
      VERSION="$CI_COMMIT_REF_SLUG"
      call_extension "before_sonar_send"
      sonar-scanner -Dsonar.links.scm=$CI_PROJECT_URL -Dsonar.host.url=$SONAR_URL -Dsonar.projectKey=$CI_PROJECT_NAME -Dsonar.projectName=$CI_PROJECT_NAME -Dsonar.gitlab.project_id=$CI_PROJECT_ID -Dsonar.issuesReport.console.enable=true -Dsonar.sourceEncoding=UTF-8 -Dsonar.projectVersion=$VERSION
      call_extension "after_sonar_send"
      ;;
esac
