#!/bin/bash

docker_login() {
  if [[ "$HUB_USER" == *"ecr"* ]]; then
    export AWS_ACCESS_KEY_ID=$ECR_ACCESS_KEY_ID
    export AWS_SECRET_ACCESS_KEY=$ECR_SECRET_ACCESS_KEY
    aws ecr get-login-password | docker login --username AWS --password-stdin $HUB_USER
  else
    docker login -u $DOCKERHUB_USERNAME -p $DOCKERHUB_PASS
  fi
}

create_hub_repo() {
  if [[ "$HUB_USER" == *"ecr"* ]]; then
    IFS=',' read -ra REGIONS <<< "$AWS_OTHERS_REGION"
    
    REGIONS+=($AWS_DEFAULT_REGION)

    for REGION in ${REGIONS[@]}; do
      aws --region $REGION ecr describe-repositories --repository-names $SVC_IMAGE || aws --region $REGION ecr create-repository --repository-name $SVC_IMAGE --image-tag-mutability IMMUTABLE --image-scanning-configuration scanOnPush=true --tags Key=Environment,Value=Development Key=Name,Value=$CI_PROJECT_NAMESPACE
    done

    IFS=',' read -ra IDS <<< "$ECR_AWS_ACCOUNT_ID_TO_PULL"

    ARNS=()

    for id in ${IDS[@]}; do
      ARNS+=("\"arn:aws:iam::$id:root\"")
    done

    # array join function
    join_by() { local IFS="$1"; shift; echo "$*"; }

    ARNS_STR=`join_by , ${ARNS[*]}`

    for REGION in ${REGIONS[@]}; do
      aws --region $REGION ecr set-repository-policy --repository-name $SVC_IMAGE --policy-text '
        {
            "Version": "2008-10-17",
            "Statement": [
              {
                "Sid": "AllowPushPull",
                "Effect": "Allow",
                "Principal": {
                  "AWS": [
                    '$ARNS_STR'
                  ]
                },
                "Action": [
                  "ecr:BatchGetImage",
                  "ecr:GetDownloadUrlForLayer"
                ]
              }
            ]
        }
      ' >> null
    done
  else
    create_dockerhub_repo
  fi
}

create_dockerhub_repo(){
  if [ -z "$SKIP_REPOCREATION" ]; then
    echo "[CI] Verificando se o repositorio ja existe no Dockerhub"

    if [ -z "$SVC_IMAGE" ]; then
      IMAGE_NAME=`cat sdl.properties | sed -n -e 's/generator.app.name=//p'`
      IMAGE_NAME=`echo ${IMAGE_NAME%%[[:cntrl:]]} | xargs`
    else
      IMAGE_NAME=$SVC_IMAGE
    fi

    echo "[CI] Validando o repo $IMAGE_NAME no Dockerhub. Para o projeto no gitlab $CI_PROJECT_NAME"

    DATA='{
      "query": "mutation($repository: String, $gitRepo: String) { createDockerhubRepo(repository: $repository, gitRepo: $gitRepo) { result } }",
      "variables": { "repository":"'$IMAGE_NAME'","gitRepo":"'$CI_PROJECT_NAME'" }
    }'

    RESPONSE_CQAT=`curl -sS \
        -X POST \
        -H "Content-Type: application/json" \
        --data "$DATA" \
        $CQAT_URL/graphql`

    ERROR_MESSAGES=`echo $RESPONSE_CQAT | jq -r ".errors | if . != null then .[].message else empty end"`

    if [ -n "$ERROR_MESSAGES" ]; then
        echo "[CI] Ocorreu um erro ao executar a validação/criação do repo."
        echo $ERROR_MESSAGES
        exit 1
    fi
  fi
}

