#!/bin/bash

set -e # Exit at first error

# Import docker helpers
. senior-ci/common/docker-helpers.sh

echo ""

if [ -e .senior-ci-extensions.sh ]; then
    echo "[CI] Carregando arquivo de extensões - .senior-ci-extensions.sh"
    . .senior-ci-extensions.sh
else
    echo "[CI] Arquivo de extensões não encontrado (.senior-ci-extensions.sh). Continuando execução padrão do CI."
fi

call_extension() {
    if [ -n "$(type -t $1)" ] && [ "$(type -t $1)" = function ]; then
        echo "[CI] Disparando hook $1 do .senior-ci-extensions.sh"
        $1
    fi
};


call_extension "before_deploy"

DOCKER_HOST="tcp://$SVC_DEPLOY_TARGET:2375"

CI_COMMIT_TAG="${CI_COMMIT_TAG//-/.}"
CI_COMMIT_TAG="${CI_COMMIT_TAG:1}"
VERSION="${CI_COMMIT_TAG:-$CI_COMMIT_REF_SLUG-SNAPSHOT}"

if [ "$SVC_NAME" == "" ]; then
  SVC_NAME=$SVC_IMAGE
fi

if [ "$SVC_TIMEZONE" == "" ]; then
  SVC_TIMEZONE="-e TZ=America/Sao_Paulo"
fi

echo ""
echo "[CI] Realizando o deploy do serviço $SVC_IMAGE:$VERSION no host $SVC_DEPLOY_TARGET"
echo ""
echo "[CI] O serviço $SVC_NAME($SVC_IMAGE:$VERSION) vai se conectar ao RabbitMQ do ambiente $CI_ENVIRONMENT_URL"
echo ""

docker_login

echo "[CI] Baixando imagem seniorsa/$SVC_IMAGE:$VERSION..."
docker -H $DOCKER_HOST pull seniorsa/$SVC_IMAGE:$VERSION

echo ""

docker -H $DOCKER_HOST rm -f $SVC_NAME

echo "[CI] Subindo container $SVC_NAME($SVC_IMAGE:$VERSION)"
echo ""
docker -H $DOCKER_HOST run -d --name=$SVC_NAME \
  -e JAVA_OPTS="$SVC_JAVA_OPTS" \
  $SVC_TIMEZONE \
  -e BROKER_HOST=$CI_ENVIRONMENT_URL \
  $SVC_ENVIRONMENT \
  --log-opt max-size=5m --log-opt max-file=1 \
  $MEMORY_LIMIT \
  --restart=unless-stopped \
  $VOLUME_MAPPING \
  seniorsa/$SVC_IMAGE:$VERSION

if [ -n "$SLACK_HOOK" ]; then
  echo "[CI] Enviando notificação no Slack..."
  echo ""
  DEPLOY_USERNAME="${GITLAB_USER_EMAIL%@senior.com.br}"
  curl -s -X POST "$SLACK_HOOK" -H 'Content-Type: application/json' -d '{ "text": "O usuário `'$DEPLOY_USERNAME'` realizou um deploy do serviço `'$SVC_IMAGE:$VERSION'` com o nome `'$SVC_NAME'` no host `'$SVC_DEPLOY_TARGET'`."}'
fi

call_extension "after_deploy"

echo ""
echo "[CI] Deploy realizado com sucesso!"
